@@ -4,7 +4,7 @@ class Encoder():
     chars = "abcdefghijklmnopqrstuvwxyz0123456789+-. _"
     def encode(self, text):
         global chars
-        text = text.lower()
+        text = str(text).lower()
         encoded = ""
         length = int(len(text))
         for i in range(0,length):
